summaryrefslogtreecommitdiffstats
path: root/src/client/connectwindow/connectwindow.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/client/connectwindow/connectwindow.cpp')
-rw-r--r--src/client/connectwindow/connectwindow.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/client/connectwindow/connectwindow.cpp b/src/client/connectwindow/connectwindow.cpp
index b1f583a..c77a5e6 100644
--- a/src/client/connectwindow/connectwindow.cpp
+++ b/src/client/connectwindow/connectwindow.cpp
@@ -27,7 +27,7 @@ ConnectWindow::ConnectWindow(QWidget *parent) : QWidget(parent)
_timerHide = 0;
_state = Idle;
_hashSslErrorCount = 0;
- _pendingConnection = NULL;
+ _pendingConnection = nullptr;
// Initialize the GUI
_ui->setupUi(this);
@@ -320,7 +320,7 @@ void ConnectWindow::onConnectionStateChange(ConnectWindow::ConnectionState state
QObject::disconnect(_pendingConnection, SIGNAL(stateChange(ConnectWindow::ConnectionState)), this, SLOT(onConnectionStateChange(ConnectWindow::ConnectionState)));
QObject::disconnect(_pendingConnection, SIGNAL(destroyed(QObject*)), this, SLOT(onConnectionClosed(QObject*)));
emit connected(_pendingConnection);
- _pendingConnection = NULL;
+ _pendingConnection = nullptr;
this->updateUserInterface();
@@ -341,12 +341,12 @@ void ConnectWindow::onComboBox_keyPressed(QKeyEvent* e)
}
/***************************************************************************//**
* If connection is closed set _pendingConnection = NULL.
* @param connection
*/
void ConnectWindow::onConnectionClosed(QObject* /* connection */ )
{
- _pendingConnection = NULL;
+ _pendingConnection = nullptr;
}
/***************************************************************************//**
@@ -341,12 +341,12 @@ void ConnectWindow::onComboBox_keyPressed(QKeyEvent* e)
}
/***************************************************************************//**
- * If connection is closed set _pendingConnection = NULL.
+ * If connection is closed set _pendingConnection = nullptr.
* @param connection
*/